Frequently Asked Questions — vectorai 0.1.0 documentation

# Frequently Asked Questions

Frequently Asked Questions

## I got a JSONDecodeError. How do I resolve this?

A JSONDecodeError can be diagnosed in the following steps:

- Check that the field entries are the same as the type that is stated in the examples and the typehints.

- If the inputs are correct, message for help on the Discord chat! (Find link on README.)

## Does the engine run on a nearest neighbor implementation?

The neighbor runs an Exact Nearest Neighbors implementation and when the number of documents exceeds 100k documents, the engine starts to run on ANN instead.

## When I insert a document with the same ID what happens to the document?

The document is over-written. In order to edit the document (ie – change a field or add a new field), you can use the edit_document function.

## How do I add a new field in a collection?

Currently, the only way is to run edit_document.

## How do I get more search results?

To get more search results, you want to change the page_size parameter. To view the next page of results, you want to use the cursor.

## Are there any limits to the API request calls?

The API requests will time out after 400 seconds. There is no limit on the size of the request or anything.

## Is Vector AI able to store images and videos?

We currently do not support storing images and videos but this can be fixed by using a link to the video or image instead.